@@ -1,12 +1,11 @@
 import os
 import glob
 import yaml
-import chevron
 import json
+import chevron
 from requests import Session
-from authenticate import Authenticate
 from urllib.parse import urljoin
-
+from .authenticate import Authenticate
 
 class Runner(Authenticate):
     def __init__(self, action_name, asset_name='asset'):
